@@ -34,6 +34,7 @@ crew_controller_aws_batch <- function(
   seconds_launch = 1800,
   seconds_idle = Inf,
   seconds_wall = Inf,
+  retry_tasks = TRUE,
   tasks_max = Inf,
   tasks_timers = 0L,
   reset_globals = TRUE,
@@ -68,7 +69,8 @@ crew_controller_aws_batch <- function(
     tls_enable = tls_enable,
     tls_config = tls_config,
     seconds_interval = seconds_interval,
-    seconds_timeout = seconds_timeout
+    seconds_timeout = seconds_timeout,
+    retry_tasks = retry_tasks
   )
   launcher <- crew_launcher_aws_batch(
     name = name,
